//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgsValidationException](index.md)/[HoraArgsValidationException](-hora-args-validation-exception.md)

# HoraArgsValidationException

[common]\
constructor(args: [HoraArgs](../-hora-args/index.md), errors: [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[HoraArgsErrorInfo](../-hora-args-error-info/index.md)&gt;)
